==> 0.1.3.tar.gz: ios/Classes/other/YDResToastView.m <==
//
//  YDResToastView.m
//  CLRealPersonDemo
//
//  Created by ydong on 2021/6/5.
//  Copyright © 2021年 ydong. All rights reserved.
//

#import "YDResToastView.h"
#import "YDDemoDefines.h"
#import "Masonry/Masonry.h"
#import "UIColor+YDLiveDetect.h"
@interface YDResToastView()<UIGestureRecognizerDelegate>;

@property (nonatomic, strong) UIView *bottomView;
@property (nonatomic, strong) UIView *bgView;

@property (nonatomic, strong) UILabel *titleLabel;
@property (nonatomic, strong) UILabel *contentLabel;

@end

@implementation YDResToastView

- (instancetype)initWithFrame:(CGRect)frame {
    self = [super initWithFrame:frame];
    if (self) {
        UITapGestureRecognizer *tap = [[UITapGestureRecognizer alloc] initWithTarget:self action:@selector(viewDidTipped)];
        tap.delegate = self;
        [self addGestureRecognizer:tap];
        self.backgroundColor = [UIColor clearColor];
        [self setupViews];
    }
    return self;
}

- (void)setupViews {
    _bottomView = [[UIView alloc] init];
    _bottomView.backgroundColor = [UIColor colorWithHexString:@"#FFFFFF"];
    _bottomView.layer.cornerRadius = 7;
    _bottomView.layer.masksToBounds = YES;
    [self addSubview:_bottomView];
    [_bottomView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.center.equalTo(self);
        make.size.mas_equalTo(CGSizeMake(270 * KWidthScale, 135 *KWidthScale));
    }];
    
    UILabel *titleLabel = [[UILabel alloc] init];
    titleLabel.text = @"操作超时";
    self.titleLabel = titleLabel;
    titleLabel.font = [UIFont fontWithName:@"PingFangSC-Regular" size:18 * KWidthScale];
    titleLabel.textColor = [UIColor colorWithHexString:@"#222222"];
    titleLabel.textAlignment = NSTextAlignmentCenter;
    [_bottomView addSubview:titleLabel];
    [titleLabel mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(self.bottomView).mas_offset(21 *KWidthScale);
        make.centerX.equalTo(self.bottomView);
    }];
    
    UILabel *contentLabel = [[UILabel alloc] init];
    contentLabel.text = @"请在规定时间内完成动作";
    contentLabel.font = [UIFont fontWithName:@"PingFangSC-Regular" size:14 * KWidthScale];
    contentLabel.textColor = [UIColor colorWithHexString:@"#888888"];
    contentLabel.textAlignment = NSTextAlignmentCenter;
    self.contentLabel = contentLabel;
    [_bottomView addSubview:contentLabel];
    [contentLabel mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(titleLabel.mas_bottom).mas_offset(8 *KWidthScale);
        make.centerX.equalTo(self.bottomView);
    }];
    
    UIView *landLine = [[UIView alloc] init];
    landLine.backgroundColor = [UIColor colorWithHexString:@"#DDDDDD"];
    [_bottomView addSubview:landLine];
    [landLine mas_makeConstraints:^(MASConstraintMaker *make) {
        make.bottom.equalTo(self.bottomView).mas_offset(-50 * KWidthScale);
        make.left.right.equalTo(self.bottomView);
        make.height.mas_equalTo(0.5);
    }];
    
    UIView *protraitLine = [[UIView alloc] init];
    protraitLine.backgroundColor = [UIColor colorWithHexString:@"#DDDDDD"];
    [_bottomView addSubview:protraitLine];
    [protraitLine mas_makeConstraints:^(MASConstraintMaker *make) {
        make.bottom.equalTo(self.bottomView);
        make.top.equalTo(landLine.mas_bottom);
        make.centerX.equalTo(self.bottomView);
        make.width.mas_equalTo(0.5);
    }];
    
    UIButton *backHomePageButton = [UIButton buttonWithType:UIButtonTypeSystem];
    [backHomePageButton addTarget:self action:@selector(backHomePageButtonDidTipped:) forControlEvents:UIControlEventTouchUpInside];
    [backHomePageButton setTitle:@"退出" forState:UIControlStateNormal];
    backHomePageButton.titleLabel.textColor = [UIColor colorWithHexString:@"#222222"];
    backHomePageButton.titleLabel.font = [UIFont fontWithName:@"PingFangSC-Regular" size:16 * KWidthScale];
    [_bottomView addSubview:backHomePageButton];
    [backHomePageButton mas_makeConstraints:^(MASConstraintMaker *make) {
        make.left.bottom.equalTo(self.bottomView);
        make.right.equalTo(protraitLine.mas_left);
        make.top.equalTo(landLine.mas_bottom);
    }];
    
    UIButton *retryButton = [UIButton buttonWithType:UIButtonTypeSystem];
    [retryButton addTarget:self action:@selector(retryButtonDidTipped:) forControlEvents:UIControlEventTouchUpInside];
    [retryButton setTitle:@"再试一次" forState:UIControlStateNormal];
    [retryButton setTitleColor:[UIColor whiteColor] forState:UIControlStateNormal];
    retryButton.backgroundColor = [UIColor colorWithHexString:@"#2D77FF"];
    retryButton.titleLabel.font = [UIFont fontWithName:@"PingFangSC-Regular" size:16 * KWidthScale];
    [_bottomView addSubview:retryButton];
    [retryButton mas_makeConstraints:^(MASConstraintMaker *make) {
         make.right.bottom.equalTo(self.bottomView);
         make.left.equalTo(protraitLine.mas_right);
         make.top.equalTo(landLine.mas_bottom);
     }];
}

- (void)viewDidTipped {
    [self hidden];
}

- (void)show:(CLToastType)toastType {
    [self hidden];
    if(toastType == CLToastTypeFaild) {
        self.titleLabel.text = @"认证失败";
        self.contentLabel.text = @"正对手机，更容易成功";
    }
    else if (toastType == CLToastTypeNoMoney) {
        self.titleLabel.text = @"认证失败";
        self.contentLabel.text = @"账号余额不足，请及时充值";
    }
    else if (toastType == CLToastTypeNetError) {
        self.titleLabel.text = @"网络异常";
        self.contentLabel.text = @"请检查网络链接";
    }
    else {
        self.titleLabel.text = @"操作超时";
        self.contentLabel.text = @"请在规定时间内完成动作";
    }
    self.bgView = [[UIView alloc] initWithFrame:[UIApplication sharedApplication].keyWindow.bounds];
    self.bgView.backgroundColor = [UIColor colorWithRed:0 green:0 blue:0 alpha:0.7];
    [self.bgView addSubview:self];
    [[UIApplication sharedApplication].keyWindow addSubview:self.bgView];
}

- (void)hidden {
    if (self) {
        [self.bgView removeFromSuperview];
    }
}

- (void)retryButtonDidTipped:(UIButton *)sender {
    [self hidden];
    if (_delegate && [_delegate respondsToSelector:@selector(retryButtonDidTipped:)]) {
        [_delegate retryButtonDidTipped:sender];
    }
}

- (void)backHomePageButtonDidTipped:(UIButton *)sender {
    [self hidden];
    if (_delegate && [_delegate respondsToSelector:@selector(backHomePageButtonDidTipped:)]) {
        [_delegate backHomePageButtonDidTipped:sender];
    }
}

- (BOOL)gestureRecognizerShouldBegin:(UIGestureRecognizer *)gestureRecognizer {
    if ([gestureRecognizer.view isDescendantOfView:self.bottomView]) {
        return NO;
    }
    return YES;
}

@end

==> 0.1.7.tar.gz: ios/Classes/other/YDResToastView.m <==
//
//  YDResToastView.m
//  
//
//  Created by ydong on 2021/6/5.
//  Copyright © 2021年 ydong. All rights reserved.
//

#import "YDResToastView.h"
#import "YDDemoDefines.h"
#import "Masonry/Masonry.h"
#import "UIColor+YDLiveDetect.h"
#import "YDLocalizationManager.h"

@interface YDResToastView()<UIGestureRecognizerDelegate>;

@property (nonatomic, strong) UIView *bottomView;
@property (nonatomic, strong) UIView *bgView;

@property (nonatomic, strong) UILabel *titleLabel;
@property (nonatomic, strong) UILabel *contentLabel;

@end

@implementation YDResToastView

- (instancetype)initWithFrame:(CGRect)frame {
    self = [super initWithFrame:frame];
    if (self) {
        UITapGestureRecognizer *tap = [[UITapGestureRecognizer alloc] initWithTarget:self action:@selector(viewDidTipped)];
        tap.delegate = self;
        [self addGestureRecognizer:tap];
        self.backgroundColor = [UIColor clearColor];
        [self setupViews];
    }
    return self;
}

- (void)setupViews {
    _bottomView = [[UIView alloc] init];
    _bottomView.backgroundColor = [UIColor colorWithHexString:@"#FFFFFF"];
    _bottomView.layer.cornerRadius = 7;
    _bottomView.layer.masksToBounds = YES;
    [self addSubview:_bottomView];
    [_bottomView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.center.equalTo(self);
        make.size.mas_equalTo(CGSizeMake(270 * KWidthScale, 180 *KWidthScale));
    }];
    
    UILabel *titleLabel = [[UILabel alloc] init];
    titleLabel.text = [self returnLocaleString:@"alive_timeout"];
    self.titleLabel = titleLabel;
    titleLabel.font = [UIFont fontWithName:@"PingFangSC-Regular" size:18 * KWidthScale];
    titleLabel.textColor = [UIColor colorWithHexString:@"#222222"];
    titleLabel.textAlignment = NSTextAlignmentCenter;
    [_bottomView addSubview:titleLabel];
    [titleLabel mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(self.bottomView).mas_offset(21 *KWidthScale);
        make.centerX.equalTo(self.bottomView);
    }];
    
    UILabel *contentLabel = [[UILabel alloc] init];
    contentLabel.text = [self returnLocaleString:@"alive_time_finish"];
    contentLabel.font = [UIFont fontWithName:@"PingFangSC-Regular" size:14 * KWidthScale];
    contentLabel.textColor = [UIColor colorWithHexString:@"#888888"];
    contentLabel.textAlignment = NSTextAlignmentCenter;
    self.contentLabel = contentLabel;
    contentLabel.numberOfLines = 0;
    [_bottomView addSubview:contentLabel];
    [contentLabel mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(titleLabel.mas_bottom).mas_offset(8 *KWidthScale);
        make.left.offset(10 * KWidthScale);
        make.right.offset(-10 * KWidthScale);
//        make.centerX.equalTo(self.bottomView);
    }];
    
    UIView *landLine = [[UIView alloc] init];
    landLine.backgroundColor = [UIColor colorWithHexString:@"#DDDDDD"];
    [_bottomView addSubview:landLine];
    [landLine mas_makeConstraints:^(MASConstraintMaker *make) {
        make.bottom.equalTo(self.bottomView).mas_offset(-50 * KWidthScale);
        make.left.right.equalTo(self.bottomView);
        make.height.mas_equalTo(0.5);
    }];
    
    UIView *protraitLine = [[UIView alloc] init];
    protraitLine.backgroundColor = [UIColor colorWithHexString:@"#DDDDDD"];
    [_bottomView addSubview:protraitLine];
    [protraitLine mas_makeConstraints:^(MASConstraintMaker *make) {
        make.bottom.equalTo(self.bottomView);
        make.top.equalTo(landLine.mas_bottom);
        make.centerX.equalTo(self.bottomView);
        make.width.mas_equalTo(0.5);
    }];
    
    UIButton *backHomePageButton = [UIButton buttonWithType:UIButtonTypeSystem];
    [backHomePageButton addTarget:self action:@selector(backHomePageButtonDidTipped:) forControlEvents:UIControlEventTouchUpInside];
    [backHomePageButton setTitle:[self returnLocaleString:@"alive_out"] forState:UIControlStateNormal];
    backHomePageButton.titleLabel.textColor = [UIColor colorWithHexString:@"#222222"];
    backHomePageButton.titleLabel.font = [UIFont fontWithName:@"PingFangSC-Regular" size:16 * KWidthScale];
    [_bottomView addSubview:backHomePageButton];
    [backHomePageButton mas_makeConstraints:^(MASConstraintMaker *make) {
        make.left.bottom.equalTo(self.bottomView);
        make.right.equalTo(protraitLine.mas_left);
        make.top.equalTo(landLine.mas_bottom);
    }];
    
    UIButton *retryButton = [UIButton buttonWithType:UIButtonTypeSystem];
    [retryButton addTarget:self action:@selector(retryButtonDidTipped:) forControlEvents:UIControlEventTouchUpInside];
    [retryButton setTitle:[self returnLocaleString:@"alive_again"] forState:UIControlStateNormal];
    [retryButton setTitleColor:[UIColor whiteColor] forState:UIControlStateNormal];
    retryButton.backgroundColor = [UIColor colorWithHexString:@"#2D77FF"];
    retryButton.titleLabel.font = [UIFont fontWithName:@"PingFangSC-Regular" size:16 * KWidthScale];
    [_bottomView addSubview:retryButton];
    [retryButton mas_makeConstraints:^(MASConstraintMaker *make) {
         make.right.bottom.equalTo(self.bottomView);
         make.left.equalTo(protraitLine.mas_right);
         make.top.equalTo(landLine.mas_bottom);
     }];
}

- (void)viewDidTipped {
    [self hidden];
}

- (void)show:(YDToastType)toastType {
    [self hidden];
    if(toastType == YDToastTypeFaild) {
        self.titleLabel.text = [self returnLocaleString:@"alive_fail"];
        self.contentLabel.text = [self returnLocaleString:@"alive_face_success"];
    }
    else if (toastType == YDToastTypeNoMoney) {
        self.titleLabel.text = [self returnLocaleString:@"alive_fail"];
        self.contentLabel.text = [self returnLocaleString:@"alive_payment"];

    }
    else if (toastType == YDToastTypeNetError) {
        self.titleLabel.text = [self returnLocaleString:@"alive_net_wrong"];
        self.contentLabel.text = [self returnLocaleString:@"alive_net_check"];

    }
    else {
        self.titleLabel.text = [self returnLocaleString:@"alive_timeout"];
        self.contentLabel.text = [self returnLocaleString:@"alive_time_finish"];
    }
    self.bgView = [[UIView alloc] initWithFrame:[UIApplication sharedApplication].keyWindow.bounds];
    self.bgView.backgroundColor = [UIColor colorWithRed:0 green:0 blue:0 alpha:0.7];
    [self.bgView addSubview:self];
    [[UIApplication sharedApplication].keyWindow addSubview:self.bgView];
}

- (void)hidden {
    if (self) {
        [self.bgView removeFromSuperview];
    }
}

- (void)retryButtonDidTipped:(UIButton *)sender {
    [self hidden];
    if (_delegate && [_delegate respondsToSelector:@selector(retryButtonDidTipped:)]) {
        [_delegate retryButtonDidTipped:sender];
    }
}

- (void)backHomePageButtonDidTipped:(UIButton *)sender {
    [self hidden];
    if (_delegate && [_delegate respondsToSelector:@selector(backHomePageButtonDidTipped:)]) {
        [_delegate backHomePageButtonDidTipped:sender];
    }
}

- (BOOL)gestureRecognizerShouldBegin:(UIGestureRecognizer *)gestureRecognizer {
    if ([gestureRecognizer.view isDescendantOfView:self.bottomView]) {
        return NO;
    }
    return YES;
}

-(NSString *)returnLocaleString:(NSString *)key{
    return [YDLocalizationManager localizedStringForKey:key language:_language];
}

@end
